@@ -18,8 +18,8 @@
  * along with gedit. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_HIGHLIGHT_MODE_SELECTOR_H__
-#define __GEDIT_HIGHLIGHT_MODE_SELECTOR_H__
+#ifndef GEDIT_HIGHLIGHT_MODE_SELECTOR_H
+#define GEDIT_HIGHLIGHT_MODE_SELECTOR_H
 
 #include <glib-object.h>
 #include <gtksourceview/gtksource.h>
@@ -41,6 +41,6 @@ void                        gedit_highlight_mode_selector_activate_selected_lang
 
 G_END_DECLS
 
-#endif /* __GEDIT_HIGHLIGHT_MODE_SELECTOR_H__ */
+#endif /* GEDIT_HIGHLIGHT_MODE_SELECTOR_H */
 
 /* ex:set ts=8 noet: */
